import { Pet } from '../types/Pet';
import { Brain, Dumbbell, Smile, Sparkles, Coins, Pizza, Trash2, Trophy, Heart, Star } from 'lucide-react';
import { PET_CLASSES } from '../data/petClasses';
import { useState } from 'react';
import InventoryModal from './modal/InventoryModal';
import SkillTreeModal from './modal/SkillTreeModal';

interface PetDisplayProps {
  pet: Pet;
  onPetUpdate: (updatedPet: Pet) => void;  // Add this prop
}

export default function PetDisplay({ pet, onPetUpdate }: PetDisplayProps) {
  const StatBar = ({ value, maxValue, label, icon: Icon }:
    { value: number; maxValue: number; label: string; icon: any; }) => (
    <div className="flex items-center space-x-2" title={label}>
      <Icon className="w-5 h-5" />
      <div className="flex-1 bg-gray-700 rounded-full h-4">
        <div
          className={`bg-blue-500 rounded-full h-4`}
          style={{ width: `${(value / maxValue) * 100}%` }}
        />
      </div>
      <span className="text-sm font-medium">{value}/{maxValue}</span>
    </div>
  );

  const ResourceCounter = ({ value, label, icon: Icon }: { value: number; label: string; icon: any }) => (
    <div className="flex items-center space-x-2 bg-gray-800 rounded-lg p-2">
      <Icon className="w-5 h-5" />
      <span>{label}:</span>
      <span className="font-bold">{value}</span>
    </div>
  );

  const [showInventoryModal, setShowInventoryModal] = useState(false);
  const [showSkillTreeModal, setShowSkillTreeModal] = useState(false);

  return (
    <div className="bg-gray-900 p-6 rounded-xl shadow-xl">
      <div className="text-center mb-8">
        <div className="text-8xl mb-4">{PET_CLASSES[pet.class].emoji}</div>
        <h2 className="text-2xl font-bold mb-2">
          <span className="bg-gradient-to-r from-blue-500 to-purple-500 text-transparent bg-clip-text">
            {pet.name}
          </span>
        </h2>
        <div className="flex items-center justify-center gap-2 mb-2">
          <Trophy className="w-5 h-5 text-yellow-500" />
          <span className="text-lg font-semibold">Level {pet.level}</span>
        </div>
        <p className={`text-${PET_CLASSES[pet.class].color}-400`}>
          {PET_CLASSES[pet.class].name}
        </p>
      </div>

      <div className="space-y-4 mb-6">
        <div className="space-y-4 mb-6">
          <StatBar
            value={pet.health}
            maxValue={pet.maxHealth}
            label="Health"
            icon={Heart}
          />
        </div>
        <StatBar
          value={pet.stats.intelligence}
          maxValue={pet.stats.maxIntelligence}
          label="Intelligence"
          icon={Brain}
        />
        <StatBar
          value={pet.stats.strength}
          maxValue={pet.stats.maxStrength}
          label="Strength"
          icon={Dumbbell}
        />
        <StatBar
          value={pet.stats.charisma}
          maxValue={pet.stats.maxCharisma}
          label="Charisma"
          icon={Smile}
        />
      </div>

      <div className="flex items-start mb-4 space-x-4">
        <div className="grid grid-cols-2 gap-4 flex-1">
          <ResourceCounter value={pet.resources.wisdom} label="Wisdom" icon={Sparkles} />
          <ResourceCounter value={pet.resources.gold} label="Gold" icon={Coins} />
          <ResourceCounter value={pet.resources.food} label="Food" icon={Pizza} />
          <ResourceCounter value={pet.resources.junk} label="Junk" icon={Trash2} />
        </div>
        <div className="flex flex-col space-y-4">
          <button
            onClick={() => setShowInventoryModal(true)}
            className="bg-green-600 hover:bg-green-700 text-white px-4 py-2 rounded"
          >
            Inventory
          </button>
          <button
            onClick={() => setShowSkillTreeModal(true)}
            className="bg-purple-600 hover:bg-purple-700 text-white px-4 py-2 rounded"
          >
            Skill Tree
          </button>
        </div>
      </div>

      {showInventoryModal && (
        <InventoryModal
          inventory={pet.inventory}
          petId={pet.id}
          onClose={() => setShowInventoryModal(false)}
          onPetUpdate={onPetUpdate}
        />
      )}
      {showSkillTreeModal && (
        <SkillTreeModal
          petId={pet.id}
          petResources={pet.resources}
          onPetUpdate={onPetUpdate}
          onClose={() => setShowSkillTreeModal(false)
          }
        />
      )}
    </div>
  );
}